export default class VisitParser {

  static isHTML(req) {
    const headers = req.headers;
    const accept = headers['accept'];
    return accept
      && accept.includes('text/html');
  }

  static parse(req) {
    const ip = this._extractIP(req);
    const userAgent = this._extractUserAgent(req);

    return {
      ip: ip,
      user_agent: userAgent,
      file: req.originalUrl,
      date: new Date()
    }
  }

  static _extractIP(req) {
    const realIp = this._extractXRealIP(req);
    if (realIp) {
      return realIp;
    }
    return req.ip || req.socket.remoteAddress;
  }

  static _extractXRealIP(req) {
    const headers = req.headers;
    return headers['x-real-ip'];
  }

  static _extractUserAgent(req) {
    const headers = req.headers;
    return headers['user-agent'];
  }

}
